@@ -11,16 +11,16 @@ import Text.Pretty.Simple (pPrint)
 import qualified Lang as L0
 
 [deflang|
-(L1 from L0:L0
+((L1 ann) from L0:L0
   (* Expr
     (- Lam)
-    (+ Lam String Expr)
+    (+ Lam ann String Expr)
     (- Nope)
   )
   (- Stmt)
 )
 |]
-deriving stock instance Show Expr
+deriving stock instance (Show ann) => Show (Expr ann)
 
 $(pure [])
 
@@ -28,7 +28,7 @@ $(pure [])
 
 main :: IO ()
 main = do
-  let theF = L0.Lam "x"
+  let theF = L0.Lam () "x"
             [ L0.Let "y" $ L0.Var "x"
             , L0.Expr () $ L0.Var "y"
             ]
@@ -36,14 +36,14 @@ main = do
   pPrint theE
   pPrint $ compile theE
 
-compile :: L0.Expr () -> Expr
+compile :: L0.Expr ann () -> Expr ann
 compile = descendExprI xlate
   where
   xlate = XlateI
     { onExprI = const Nothing
-    , onExprLamI = \var body -> case body of
-        [] -> Lam var $ Var var
-        L0.Expr () e1 : _ -> Lam var $ compile e1
-        L0.Let _ body1 : _ -> Lam var $ compile body1
+    , onExprLamI = \ann var body -> case body of
+        [] -> Lam ann var $ Var var
+        L0.Expr () e1 : _ -> Lam ann var $ compile e1
+        L0.Let _ body1 : _ -> Lam ann var $ compile body1
     , onExprNopeI = Var
     }
