@@ -55,8 +55,8 @@ data XlateDef = XlateDef
   , xlateFParam :: TH.Name -- ^ a type for an Applicative parameter
   , xlateNonterms :: [XlateNontermDef]
     -- ^ information about the syntactic cateories shared by both source and target
-    -- this is used to allow users to override the bahavior of automatic translation
-  , xlateProds :: [XlateProd] -- FIXME these should go under xlateNonterms, probly
+    -- this is used to allow users to override the behavior of automatic translation
+  , xlateProds :: [XlateProd] -- FIXME these should go under xlateNonterms, probably
     -- ^ information about the productions in the source that are missing in the target
     -- this is so that we require the user to supply these in an Xlate type
   , xlateFrom :: Language 'Valid UpDotName
@@ -358,7 +358,7 @@ defineDescend l1 l2 xdef = do
       , "Some (hopefully most) of this function was automatically generated by nanopass."
       , unwords
         [ "It is parameterized by an t'Xlate', which"
-        , "fills holes for which nanopass could not automatcially determine a translation, and also"
+        , "fills holes for which nanopass could not automatically determine a translation, and also"
         , "allows for automatic translation to be overridden."
         ]
       ]
